Index: trunk/Ohana/src/opihi/pcontrol/QueueOps.c
===================================================================
--- trunk/Ohana/src/opihi/pcontrol/QueueOps.c	(revision 3187)
+++ trunk/Ohana/src/opihi/pcontrol/QueueOps.c	(revision 3203)
@@ -2,19 +2,19 @@
 
 /* get object from point in stack (negative == distance from end) */
-void *GetQueue (Queue *queue, int where) {
+void *GetStack (Stack *stack, int where) {
 
   int i;
   void *object;
   
-  /* QUEUE_TOP == 0, QUEUE_BOTTOM == -1 */
+  /* STACK_TOP == 0, STACK_BOTTOM == -1 */
   /* this code correctly handles the negative 'where' and Nobject == 0 */
-  if (where < 0) where += queue[0].Nobject;
+  if (where < 0) where += stack[0].Nobject;
   if (where < 0) return (NULL);
-  if (where >= queue[0].Nobject) return (NULL);
+  if (where >= stack[0].Nobject) return (NULL);
 
-  object = queue[0].object[where];
-  queue[0].Nobject --;
-  for (i = where; i < queue[0].Nobject; i++) {
-    queue[0].object[i] = queue[0].object[i+1];
+  object = stack[0].object[where];
+  stack[0].Nobject --;
+  for (i = where; i < stack[0].Nobject; i++) {
+    stack[0].object[i] = stack[0].object[i+1];
   }
   return (object);
@@ -22,42 +22,42 @@
 
 /* push object on top of stack */
-int PutQueue (Queue *queue, int where, void *object) {
+int PutStack (Stack *stack, int where, void *object) {
 
   int i;
 
-  /* QUEUE_TOP == 0, QUEUE_BOTTOM == -1 */
+  /* STACK_TOP == 0, STACK_BOTTOM == -1 */
   /* this code correctly handles the negative 'where' and Nobject == 0 */
-  if (where < 0) where += queue[0].Nobject + 1;
+  if (where < 0) where += stack[0].Nobject + 1;
   if (where < 0) return (FALSE);
-  if (where > queue[0].Nobject) return (FALSE);
+  if (where > stack[0].Nobject) return (FALSE);
 
-  /* extend queue as needed */
-  if (queue[0].Nobject >= queue[0].NOBJECT) {
-    queue[0].NOBJECT += 100;
-    REALLOCATE (queue[0].object, void *, queue[0].NOBJECT);
+  /* extend stack as needed */
+  if (stack[0].Nobject >= stack[0].NOBJECT) {
+    stack[0].NOBJECT += 100;
+    REALLOCATE (stack[0].object, void *, stack[0].NOBJECT);
   }
 
-  for (i = queue[0].Nobject; i > where; i--) {
-    queue[0].object[i] = queue[0].object[i-1];
+  for (i = stack[0].Nobject; i > where; i--) {
+    stack[0].object[i] = stack[0].object[i-1];
   }
-  queue[0].object[where] = object;
-  queue[0].Nobject ++;
+  stack[0].object[where] = object;
+  stack[0].Nobject ++;
   return (TRUE);
 }
 
-/* allocate queue, setup with default values, allocate data */
-Queue *InitQueue () {
+/* allocate stack, setup with default values, allocate data */
+Stack *InitStack () {
 
-  Queue *queue;
+  Stack *stack;
 
-  ALLOCATE (queue, Queue, 1);
+  ALLOCATE (stack, Stack, 1);
 
-  queue[0].Nobject = 0;
-  queue[0].NOBJECT = 50;
-  ALLOCATE (queue[0].object, void *, queue[0].NOBJECT);
-  return (queue);
+  stack[0].Nobject = 0;
+  stack[0].NOBJECT = 50;
+  ALLOCATE (stack[0].object, void *, stack[0].NOBJECT);
+  return (stack);
 }
 
-/* these queues are not super efficient, and should probably be replaced with linked lists, 
+/* these stacks are not super efficient, and should probably be replaced with linked lists, 
    but I find these easier to get my brain around
 */
